@@ -110,7 +110,7 @@ xfpm_about (gpointer data)
   };
 
   gtk_show_about_dialog (NULL,
-       "copyright", "Copyright \302\251 2008-2011 Ali Abdallah\nCopyright \302\251 2011-2012 Nick Schermer\nCopyright \302\251 2013-2015 Eric Koegel, Harald Judt, Simon Steinbeiß",
+       "copyright", "Copyright \302\251 2008-2011 Ali Abdallah\nCopyright \302\251 2011-2012 Nick Schermer\nCopyright \302\251 2013-2015 Eric Koegel, Harald Judt, Simon Steinbeiß\nCopyright \302\251 2016-2023 The Xfce development team",
        "destroy-with-parent", TRUE,
        "authors", authors,
        "artists", artists,
@@ -148,16 +148,17 @@ xfpm_is_multihead_connected (void)
 }
 
 GdkPixbuf *
-xfpm_icon_load (const gchar *icon_name, gint size)
+xfpm_icon_load (const gchar *icon_name, gint size, gint scale_factor)
 {
   GdkPixbuf *pix = NULL;
   GError *error = NULL;
 
-  pix = gtk_icon_theme_load_icon (gtk_icon_theme_get_default (),
-                                  icon_name,
-                                  size,
-                                  GTK_ICON_LOOKUP_FORCE_SIZE,
-                                  &error);
+  pix = gtk_icon_theme_load_icon_for_scale (gtk_icon_theme_get_default (),
+                                            icon_name,
+                                            size,
+                                            scale_factor,
+                                            GTK_ICON_LOOKUP_FORCE_SIZE,
+                                            &error);
 
   if ( error )
   {
